# Camille [![Build Status](https://travis-ci.org/Statoil/camille.svg?branch=master)](https://travis-ci.org/Statoil/camille)[![Codacy Badge](https://api.codacy.com/project/badge/Grade/dd2bd7f03ee84c73bef3f4a96c02bddc)](https://www.codacy.com/project/JensGM/camille/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=Statoil/camille&amp;utm_campaign=Badge_Grade_Dashboard)

A dataframe processing toolbox.
